#include "compattrbimpl.h"

#include <stdio.h>
#include <stdlib.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qvalidator.h>
#include <qmessagebox.h>



/* 
 *  Constructs a compattrb which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
compattrb::compattrb( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : compattrbBase( parent, name, modal, fl )
{
	m_ref			="U";
	m_name			="NEWCOMPONENT";
	m_width			=2;
	m_height		=2;
	m_block			=1;
	m_usepattern	=false;

}

/*  
 *  Destroys the object and frees any allocated resources
 */
compattrb::~compattrb()
{
    // no need to delete child widgets, Qt does it all for us
}

int compattrb::exec()
{
	EditName->setText(m_name);
	EditPrefix->setText(m_ref);
	char sz[32];
	sprintf(sz,"%d",m_width);
	EditWidth->setText(sz);
	sprintf(sz,"%d",m_height);
	EditHeight->setText(sz);
	sprintf(sz,"%d",m_block);
	EditBlock->setText(sz);
	CheckBox1->setChecked(m_usepattern);

	EditName->setFocus();
	return compattrbBase::exec();
}

void compattrb::setBlock(int block)
{
	if(block<1) m_block = 1;
	else if(block>255) m_block = 255;
	else m_block = block;
}

void compattrb::setWidth(int width)
{
	if(width<1) m_width = 1;
	else if(width>255) m_width = 255;
	else m_width = width;
}

void compattrb::setHeight(int height)
{
	if(height<1) m_height = 1;
	else if(height>255) m_height = 255;
	else m_height = height;
}

void compattrb::accept()
{
	int width;
	int height;
	int block;
	bool usepattern;

	usepattern = CheckBox1->isChecked();
	QString str;
	str = EditWidth->text();
	width = atoi(str.latin1());
	if(usepattern && (width<1 || width>50) ){
		QMessageBox::critical( this, "Component attribute",
							"Width must be between 1 and 50 if the component uses a pattern.",
							"OK",QString::null,QString::null,0,0);
		return;
	}else if(!usepattern && (width<1 || width>255) ){
		QMessageBox::critical( this, "Component attribute",
							"Width must be between 1 and 255.",
							"OK",QString::null,QString::null,0,0);
		return;
	} 
	
	str = EditHeight->text();
	height = atoi(str.latin1());

	if(usepattern && (height<1 || height>50) ){
		QMessageBox::critical( this, "Component attribute",
							"Height must be between 1 and 50 if the component uses a pattern.",
							"OK",QString::null,QString::null,0,0);
		return;
	}else if(!usepattern && (height<1 || height>255) ){
		QMessageBox::critical( this, "Component attribute",
							"Height must be between 1 and 255.",
							"OK",QString::null,QString::null,0,0);
		return;
	} 

	str = EditBlock->text();
	block = atoi(str.latin1());
	if(block<1 || block>255){
		QMessageBox::critical( this, "Component attribute",
							"Block must be between 1 and 255.",
							"OK",QString::null,QString::null,0,0);
		return;
	}

	m_name = EditName->text();
	if(m_name.isEmpty())m_name ="NEWCOMPONENT";

	m_ref = EditPrefix->text();
	m_width = width;
	m_height = height;
	m_block = block;
	m_usepattern = usepattern;
	compattrbBase::accept();
}